@@ -74,8 +74,13 @@ CDesktop::CDesktop()
     int settings = 0;
     XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
 		    PropModeReplace, (unsigned char*)&settings, 1);
-    
-    renderer = new QSvgRenderer(QLatin1String(":icons/rds.svg"), this);
+
+    if (QFile( QDir::homePath()+"/MyDocs/rds.svg").exists())
+        renderer = new QSvgRenderer(QDir::homePath()+"/MyDocs/rds.svg", this);
+    else
+        renderer = new QSvgRenderer(QLatin1String(":icons/rds.svg"), this);
+
+    resize( renderer->defaultSize());
 
     // Mafw Meta data connection
     rdsMafw = new CMafwMeta(this);
@@ -89,13 +94,36 @@ CDesktop::CDesktop()
     // Rds Broadcast writer
     rdsSms = new CSms(this);
 
+    // Create Radio Tuner
+    fmRadio = new CFMRadio(this);
+
     // Connect signal changed
     connect(rdsMafw, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
     connect(rdsRTCom, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
     connect(rdsSms, SIGNAL(sigChanged(QString,int)), rdsBroadcast, SLOT(slotSetText(QString,int)));
 
     QDBusConnection::systemBus().connect( 0, FMTX_PATH, FMTX_IF,  "info", this, SLOT(slotFMTXChanged(QString,QString)));
-    
+
+    // Plug start button
+    startButton = new QPushButton(this);
+    startButton->setCheckable(true);
+    //Transparent button
+    startButton->setFlat(true);
+    startButton->setUpdatesEnabled(false);
+    connect(startButton, SIGNAL(toggled(bool)), this, SLOT(slotToggleFM(bool)));
+
+    nextButton = new QPushButton(this);
+    //Transparent button
+    nextButton->setFlat(true);
+    nextButton->setUpdatesEnabled(false);
+    connect(nextButton, SIGNAL(clicked(bool)), this, SLOT(slotClickedNext(bool)));
+
+    previousButton = new QPushButton(this);
+    //Transparent button
+    previousButton->setFlat(true);
+    previousButton->setUpdatesEnabled(false);
+    connect(previousButton, SIGNAL(clicked(bool)), this, SLOT(slotClickedPrevious(bool)));
+
 }
 
 
@@ -174,42 +202,76 @@ void CDesktop::drawStatus(QPainter *p, QRectF rect, bool status)
 
 void CDesktop::drawDesktop(QPainter *p)
 {
-    QRectF mp3Status = renderer->boundsOnElement("MP3_STATUS");
-    if ( state)
-    	drawStatus(p, mp3Status , CMafwMeta::self().getEnable() );
+    if ( CMafwMeta::self().getEnable())
+        renderer->render(p, "Music_On_Icon", renderer->boundsOnElement("Music_On_Icon"));
+    else
+        renderer->render(p, "Music_Off_Icon", renderer->boundsOnElement("Music_Off_Icon"));
 
-    QRectF rtcomStatus = renderer->boundsOnElement("RTCOM_STATUS");
-    if ( state)
-    	drawStatus(p, rtcomStatus , CRTCom::self().getEnable() );
-    
-    QRectF smsStatus = renderer->boundsOnElement("SMS_STATUS");
-    if ( state)
-        drawStatus(p, smsStatus , CSms::self().getEnable() );
+    if ( CSms::self().getEnable())
+        renderer->render(p, "SMS_On_Icon", renderer->boundsOnElement("SMS_On_Icon"));
+    else
+        renderer->render(p, "SMS_Off_Icon", renderer->boundsOnElement("SMS_Off_Icon"));
 
+    if ( CRTCom::self().getEnable())
+        renderer->render(p, "Phone_On_Icon", renderer->boundsOnElement("Phone_On_Icon"));
+    else
+        renderer->render(p, "Phone_Off_Icon", renderer->boundsOnElement("Phone_Off_Icon"));
+
+    p->save();
     QFont localFont = p->font();
     localFont.setPointSize(14);
     p->setFont(localFont);
     p->setPen(Qt::white);
-
-    QRectF mp3Rect = renderer->boundsOnElement("MP3");
-    p->drawText(mp3Rect , Qt::AlignLeft, tr("Musics tags") ); 
     
-    QRectF rtcomRect = renderer->boundsOnElement("RTCOM");
-    p->drawText(rtcomRect , Qt::AlignLeft, tr("Call Status") ); 
-    
-    QRectF smsRect = renderer->boundsOnElement("SMS");
-    p->drawText(smsRect, Qt::AlignLeft, tr("SMS Message") ); 
-
-    localFont = p->font();
-    localFont.setPointSize(16);
-    localFont.setBold(true);
-    p->setFont(localFont);
-    
-    QRectF titleRect = renderer->boundsOnElement("TITLE");
+    QRectF titleRect = renderer->boundsOnElement("Station_Name");
     if ( state)
-    	p->drawText(titleRect , Qt::AlignLeft, CRdsBroadcast::self().getDefText() ); 
+        if ((titleRect.height() == 0) &&  (titleRect.width() == 0))
+            p->drawText(titleRect.x(), titleRect.y(), CRdsBroadcast::self().getDefText());
+        else
+            p->drawText(titleRect, CRdsBroadcast::self().getDefText());
     else
-    	p->drawText(titleRect , Qt::AlignLeft, tr("Transmiter off") ); 
+        if ((titleRect.height() == 0) &&  (titleRect.width() == 0))
+            p->drawText(titleRect.x(), titleRect.y(), tr(""));
+        else
+            p->drawText(titleRect, CRdsBroadcast::self().getDefText());
+
+    QRectF frequency = renderer->boundsOnElement("Station_Freq");
+
+    if ((frequency.height() == 0) &&  (frequency.width() == 0))
+        p->drawText(frequency.x(), frequency.y(), QString("%1").arg( CFMRadio::self().getFrequency()/1000 ));
+    else
+        p->drawText(frequency,  QString("%1 Mhz").arg( CFMRadio::self().getFrequency()/1000) );
+
+    localFont.setPointSize(9);
+    p->setFont(localFont);
+
+    QRectF freqStepPlus = renderer->boundsOnElement("Amount_Plus");
+    p->drawText(freqStepPlus.x(), freqStepPlus.y(),  QString("%1 Mhz").arg( CFMRadio::self().getStep()/1000 ) );
+
+    QRectF freqStepMin = renderer->boundsOnElement("Amount_Min");
+    p->drawText(freqStepMin.x(), freqStepMin.y(),  QString("%1 Mhz").arg( CFMRadio::self().getStep()/1000) );
+
+
+    p->restore();
+
+    if ( state )
+    {
+        // Draw stop button in place of FM icon
+        renderer->render(p, "TX_Status_On", renderer->boundsOnElement("TX_Status_On"));
+        renderer->render(p, "FM_On_Icon", renderer->boundsOnElement("FM_On_Icon"));
+        startButton->setGeometry(renderer->boundsOnElement("FM_On_Icon").toAlignedRect());
+    }
+    else
+    {
+        // Draw start button in place of FM icon
+        renderer->render(p, "TX_Status_Off", renderer->boundsOnElement("TX_Status_Off"));
+        renderer->render(p, "FM_Off_Icon", renderer->boundsOnElement("FM_Off_Icon"));
+        startButton->setGeometry(renderer->boundsOnElement("FM_On_Icon").toAlignedRect());
+    }
+
+    nextButton->setGeometry(renderer->boundsOnElement("Plus").toAlignedRect());
+    previousButton->setGeometry(renderer->boundsOnElement("Min").toAlignedRect());
+
 }
 
 void CDesktop::slotFMTXChanged(QString type, QString status)
@@ -223,3 +285,21 @@ void CDesktop::slotFMTXChanged(QString type, QString status)
 	update();
     }
 }
+
+void CDesktop::slotToggleFM(bool checked){
+    CFMRadio::self().setState(checked);
+}
+
+void CDesktop::slotClickedNext(bool checked){
+    int stepFreq = CFMRadio::self().getStep();
+    int curFreq = CFMRadio::self().getFrequency();
+    CFMRadio::self().setFrequency(curFreq + stepFreq);
+    qDebug() << "Current frequency=" << CFMRadio::self().getFrequency();
+}
+
+void CDesktop::slotClickedPrevious(bool checked){
+    int stepFreq = CFMRadio::self().getStep();
+    int curFreq = CFMRadio::self().getFrequency();
+    CFMRadio::self().setFrequency(curFreq - stepFreq);
+    qDebug() << "Current frequency=" << CFMRadio::self().getFrequency();
+}
