@@ -41,6 +41,7 @@ class CMafwMeta : public IRdsText
 	// state of plug on or off
         void    setEnable(bool value);
 	bool getEnable();
+        bool getState();
 	// connect plug
         void    setConnect(int value);
 
@@ -61,6 +62,8 @@ class CMafwMeta : public IRdsText
 	int timeout;
 	// plug status
 	bool state;
+        // Tx connect state
+        bool connect;
 
     private slots:
 	void slotMetadataChanged(QString meta, uint state,QDBusVariant data);
